Module content

Module content 

Full file content inclusion.

Functions

extract_summary
Extract first N lines from content as a summary.
include_contents
Include file contents that fit within budget. Returns a list of (relative_path, content) tuples.
read_content
Read file content, returning None if file is binary or too large.
read_entry_content
Read file content for an entry.