Full file content inclusion.
Functions
- extract_
summary - Extract first N lines from content as a summary.
- include_
contents - Include file contents that fit within budget. Returns a list of (relative_path, content) tuples.
- read_
content - Read file content, returning None if file is binary or too large.
- read_
entry_ content - Read file content for an entry.